package com.compomics.marc;

import com.compomics.util.Util;
import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;

/**
 * Convenience classes to work with mgf files
 *
 * @author Marc Vaudel
 */
public class MgfHandling {

    
    public static void main(String[] args) {
        MgfHandling m = new MgfHandling();

        try {
            m.removeZeros();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
    
    /**
     * Removes the zero intensity peaks from the mgf files of a folder and writes a new file in another folder.
     * 
     * @throws IOException 
     */
    private void removeZeros() throws IOException {
        File inFolder = new File("D:\\projects\\Leishmania\\mgf");
        File outFolder = new File("D:\\projects\\Leishmania\\mgf_no_zeros");
        for (File inFile : inFolder.listFiles()) {
            String name = inFile.getName();
            if (name.endsWith(".mgf")) {
                File destinationFile = new File(outFolder, name);
                removeZeros(inFile, destinationFile);
            }
        }
    }
    
    /**
     * Removes the zero intensity peaks from an mgf file writes a new file.
     * 
     * @param inFile
     * @param outFile
     * @throws IOException 
     */
    private void removeZeros(File inFile, File outFile) throws IOException {

        BufferedReader br = new BufferedReader(new FileReader(inFile));
        try {
            String line;
            BufferedWriter bw = new BufferedWriter(new FileWriter(outFile));
            try {
                while ((line = br.readLine()) != null) {
                    boolean peak = true;
                    boolean zero = false;
                    String[] split = line.split(" ");
                    if (split.length == 2) {
                        try {
                            Double mass = new Double(split[0]);
                        } catch (Exception e) {
                            peak = false;
                        }
                        if (peak) {
                            try {
                                Double intensity = new Double(split[1]);
                                if (intensity == 0.0) {
                                    zero = true;
                                }
                            } catch (Exception e) {
                                throw new IllegalArgumentException("Line not recognized:\n" + line);
                            }
                        }
                    } else {
                        peak = false;
                    }
                    if (!peak || !zero) {
                        bw.write(line);
                        bw.newLine();
                    }
                }
            } finally {
                bw.close();
            }
        } finally {
            br.close();
        }
    }

}
